@@ -21,7 +21,6 @@
 #include "httpcredentialstext.h"
 #include "libsync/logger.h"
 #include "libsync/theme.h"
-#include "netrcparser.h"
 #include "networkjobs/checkserverjobfactory.h"
 #include "networkjobs/jsonjob.h"
 #include "platform.h"
@@ -32,10 +31,8 @@
 #include <QDebug>
 #include <QFile>
 #include <QFileInfo>
-#include <QJsonDocument>
 #include <QJsonObject>
 #include <QNetworkProxy>
-#include <QStringList>
 #include <QUrl>
 
 #include <iostream>
@@ -60,7 +57,6 @@ struct CmdOptions
     QString proxy;
     bool silent = false;
     bool trustSSL = false;
-    bool useNetrc = false;
     bool interactive = true;
     bool ignoreHiddenFiles = true;
     QString exclude;
@@ -73,10 +69,12 @@ struct CmdOptions
 struct SyncCTX
 {
     explicit SyncCTX(const CmdOptions &cmdOptions)
-        : options { cmdOptions }
+        : options{cmdOptions}
+        , promptRemoveAllFiles(cmdOptions.interactive)
     {
     }
     CmdOptions options;
+    bool promptRemoveAllFiles;
     AccountPtr account;
     QString user;
 };
@@ -84,7 +82,7 @@ struct SyncCTX
 /* If the selective sync list is different from before, we need to disable the read from db
   (The normal client does it in SelectiveSyncDialog::accept*)
  */
-void selectiveSyncFixup(OCC::SyncJournalDb *journal, const QStringList &newList)
+void selectiveSyncFixup(OCC::SyncJournalDb *journal, const QSet<QString> &newListSet)
 {
     SqlDatabase db;
     if (!db.openOrCreateReadWrite(journal->databaseFilePath())) {
@@ -93,37 +91,42 @@ void selectiveSyncFixup(OCC::SyncJournalDb *journal, const QStringList &newList)
 
     bool ok;
 
-    auto oldBlackListSet = journal->getSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, &ok).toSet();
+    const auto oldBlackListSet = journal->getSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, &ok);
     if (ok) {
-        auto blackListSet = newList.toSet();
-        const auto changes = (oldBlackListSet - blackListSet) + (blackListSet - oldBlackListSet);
+        const auto changes = (oldBlackListSet - newListSet) + (newListSet - oldBlackListSet);
         for (const auto &it : changes) {
             journal->schedulePathForRemoteDiscovery(it);
         }
 
-        journal->setSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, newList);
+        journal->setSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList, newListSet);
     }
 }
 
 
 void sync(const SyncCTX &ctx)
 {
-    QStringList selectiveSyncList;
-    if (!ctx.options.unsyncedfolders.isEmpty()) {
-        QFile f(ctx.options.unsyncedfolders);
-        if (!f.open(QFile::ReadOnly)) {
-            qCritical() << "Could not open file containing the list of unsynced folders: " << ctx.options.unsyncedfolders;
-        } else {
-            // filter out empty lines and comments
-            selectiveSyncList = QString::fromUtf8(f.readAll()).split(QLatin1Char('\n')).filter(QRegExp(QStringLiteral("\\S+"))).filter(QRegExp(QStringLiteral("^[^#]")));
+    const auto selectiveSyncList = [&]() -> QSet<QString> {
+        if (!ctx.options.unsyncedfolders.isEmpty()) {
+            QFile f(ctx.options.unsyncedfolders);
+            if (!f.open(QFile::ReadOnly)) {
+                qCritical() << "Could not open file containing the list of unsynced folders: " << ctx.options.unsyncedfolders;
+            } else {
+                // filter out empty lines and comments
+                auto selectiveSyncList = QString::fromUtf8(f.readAll())
+                                             .split(QLatin1Char('\n'))
+                                             .filter(QRegularExpression(QStringLiteral("\\S+")))
+                                             .filter(QRegularExpression(QStringLiteral("^[^#]")));
 
-            for (int i = 0; i < selectiveSyncList.count(); ++i) {
-                if (!selectiveSyncList.at(i).endsWith(QLatin1Char('/'))) {
-                    selectiveSyncList[i].append(QLatin1Char('/'));
+                for (int i = 0; i < selectiveSyncList.count(); ++i) {
+                    if (!selectiveSyncList.at(i).endsWith(QLatin1Char('/'))) {
+                        selectiveSyncList[i].append(QLatin1Char('/'));
+                    }
                 }
+                return {selectiveSyncList.cbegin(), selectiveSyncList.cend()};
             }
         }
-    }
+        return {};
+    }();
 
     const QString dbPath = ctx.options.source_dir + SyncJournalDb::makeDbName(ctx.options.source_dir);
     auto db = new SyncJournalDb(dbPath, qApp);
@@ -142,9 +145,9 @@ void sync(const SyncCTX &ctx)
     QObject::connect(engine, &SyncEngine::finished, engine, [engine, ctx, restartCount = std::make_shared<int>(0)](bool result) {
         if (!result) {
             qWarning() << "Failed to sync";
-            qApp->exit(EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         } else {
-            if (engine->isAnotherSyncNeeded() != NoFollowUpSync) {
+            if (engine->isAnotherSyncNeeded()) {
                 if (*restartCount < ctx.options.restartTimes) {
                     (*restartCount)++;
                     qDebug() << "Restarting Sync, because another sync is needed" << *restartCount;
@@ -157,39 +160,6 @@ void sync(const SyncCTX &ctx)
             }
         }
     });
-    QObject::connect(engine, &SyncEngine::aboutToRemoveAllFiles, engine, [ctx](OCC::SyncFileItem::Direction dir, const std::function<void(bool)> &abort) {
-        if (!ctx.options.interactive) {
-            abort(false);
-        } else {
-            if (dir == SyncFileItem::Down) {
-                qInfo() << "All files in the sync folder '" << ctx.options.remoteFolder << "' folder were deleted on the server.";
-                qInfo() << "These deletes will be synchronized to your local sync folder, making such files "
-                        << "unavailable unless you have a right to restore.";
-                qInfo() << "If you decide to keep the files, they will be re-synced with the server if you have rights to do so.";
-                qInfo() << "If you decide to delete the files, they will be unavailable to you, unless you are the owner.";
-
-
-            } else {
-                qInfo() << "All the files in your local sync folder '" << ctx.options.source_dir << "' were deleted. These deletes will be "
-                        << "synchronized with your server, making such files unavailable unless restored.";
-                qInfo() << "Are you sure you want to sync those actions with the server?";
-                qInfo() << "If this was an accident and you decide to keep your files, they will be re-synced from the server.";
-            }
-            std::string s;
-            while (true) {
-                qInfo() << "Remove all files? [y,n]";
-                std::getline(std::cin, s);
-                if (s == "y") {
-                    abort(false);
-                } else if (s == "n") {
-                    abort(true);
-                } else {
-                    continue;
-                }
-                return;
-            }
-        }
-    });
     QObject::connect(engine, &SyncEngine::syncError, engine,
         [](const QString &error) { qWarning() << "Sync error:" << error; });
     engine->setIgnoreHiddenFiles(ctx.options.ignoreHiddenFiles);
@@ -203,16 +173,16 @@ void sync(const SyncCTX &ctx)
 
     // Always try to load the user-provided exclude list if one is specified
     if (hasUserExcludeFile) {
-        engine->excludedFiles().addExcludeFilePath(ctx.options.exclude);
+        engine->addExcludeList(ctx.options.exclude);
     }
     // Load the system list if available, or if there's no user-provided list
     if (!hasUserExcludeFile || QFile::exists(systemExcludeFile)) {
-        engine->excludedFiles().addExcludeFilePath(systemExcludeFile);
+        engine->addExcludeList(systemExcludeFile);
     }
 
-    if (!engine->excludedFiles().reloadExcludeFiles()) {
+    if (!engine->reloadExcludes()) {
         qCritical() << "Cannot load system exclude list or list supplied via --exclude";
-        qApp->exit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
     }
     engine->startSync();
 }
@@ -222,8 +192,7 @@ void setupCredentials(SyncCTX &ctx)
     // Order of retrieval attempt (later attempts override earlier ones):
     // 1. From URL
     // 2. From options
-    // 3. From netrc (if enabled)
-    // 4. From prompt (if interactive)
+    // 3. From prompt (if interactive)
 
     const auto &url = ctx.options.target_url;
     ctx.user = url.userName();
@@ -237,15 +206,6 @@ void setupCredentials(SyncCTX &ctx)
         password = ctx.options.password;
     }
 
-    if (ctx.options.useNetrc) {
-        NetrcParser parser;
-        if (parser.parse()) {
-            NetrcParser::LoginPair pair = parser.find(url.host());
-            ctx.user = pair.first;
-            password = pair.second;
-        }
-    }
-
     if (!ctx.options.proxy.isNull()) {
         QString host;
         uint32_t port = 0;
@@ -262,14 +222,14 @@ void setupCredentials(SyncCTX &ctx)
             port = pList.at(2).toUInt(&ok);
             if (!ok || port > std::numeric_limits<uint16_t>::max()) {
                 qCritical() << "Invalid port number";
-                qApp->exit(EXIT_FAILURE);
+                exit(EXIT_FAILURE);
             }
 
             QNetworkProxyFactory::setUseSystemConfiguration(false);
             QNetworkProxy::setApplicationProxy(QNetworkProxy(QNetworkProxy::HttpProxy, host, static_cast<uint16_t>(port)));
         } else {
             qCritical() << "Could not read httpproxy. The proxy should have the format \"http://hostname:port\".";
-            qApp->exit(EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         }
     }
 
@@ -280,7 +240,7 @@ void setupCredentials(SyncCTX &ctx)
         QFile f(ctx.options.unsyncedfolders);
         if (!f.open(QFile::ReadOnly)) {
             qCritical() << "Cannot read unsyncedfolders file '" << ctx.options.unsyncedfolders << "': " << f.errorString();
-            qApp->exit(EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         }
         f.close();
     }
@@ -299,7 +259,7 @@ void setupCredentials(SyncCTX &ctx)
                 qCritical() << e.errorString();
             }
             qCritical() << "If you trust the certificate and want to ignore the errors, use the --trust option.";
-            qApp->exit(EXIT_FAILURE);
+            exit(EXIT_FAILURE);
         });
     }
 }
@@ -312,7 +272,10 @@ CmdOptions parseOptions(const QStringList &app_args)
     parser.setApplicationDescription(QStringLiteral("%1 version %2 - command line client tool").arg(QCoreApplication::instance()->applicationName(), OCC::Version::displayString()));
 
     // this little snippet saves a few lines below
-    auto addOption = [&parser](const QCommandLineOption &option) {
+    auto addOption = [&parser](QCommandLineOption &&option, std::optional<QCommandLineOption::Flag> &&flags = {}) {
+        if (flags.has_value()) {
+            option.setFlags(flags.value());
+        }
         parser.addOption(option);
         return option;
     };
@@ -323,10 +286,10 @@ CmdOptions parseOptions(const QStringList &app_args)
     auto excludeOption = addOption({ { QStringLiteral("exclude") }, QStringLiteral("Path to an exclude list [file]"), QStringLiteral("file") });
     auto unsyncedfoldersOption = addOption({ { QStringLiteral("unsyncedfolders") }, QStringLiteral("File containing the list of unsynced remote folders (selective sync)"), QStringLiteral("file") });
 
-    auto serverOption = addOption({ { QStringLiteral("server") }, QStringLiteral("Use [url] as the location of the server. OCIS only (server location and spaces url can differ)"), QStringLiteral("url") });
+    auto serverOption = addOption({{QStringLiteral("server")},
+        QStringLiteral("Use [url] as the location of the server. OCIS only (server location and spaces URL can differ)"), QStringLiteral("url")});
     auto userOption = addOption({ { QStringLiteral("u"), QStringLiteral("user") }, QStringLiteral("Use [name] as the login name"), QStringLiteral("name") });
-    auto passwordOption = addOption({ { QStringLiteral("p"), QStringLiteral("password") }, QStringLiteral("Use [pass] as password"), QStringLiteral("password") });
-    auto useNetrcOption = addOption({ { QStringLiteral("n") }, QStringLiteral("Use netrc (5) for login") });
+    auto passwordOption = addOption({{QStringLiteral("p"), QStringLiteral("password")}, QStringLiteral("Use [pass] as password"), QStringLiteral("password")});
 
     auto nonInterActiveOption = addOption({ { QStringLiteral("non-interactive") }, QStringLiteral("Do not block execution with interaction") });
     auto maxRetriesOption = addOption({ { QStringLiteral("max-sync-retries") }, QStringLiteral("Retries maximum n times (default to 3)"), QStringLiteral("n") });
@@ -336,11 +299,14 @@ CmdOptions parseOptions(const QStringList &app_args)
 
     auto logdebugOption = addOption({ { QStringLiteral("logdebug") }, QStringLiteral("More verbose logging") });
 
+    const auto testCrashReporter =
+        addOption({{QStringLiteral("crash")}, QStringLiteral("Crash the client to test the crash reporter")}, QCommandLineOption::HiddenFromHelp);
+
     parser.addHelpOption();
     parser.addVersionOption();
 
     parser.addPositionalArgument(QStringLiteral("source_dir"), QStringLiteral("The source dir"));
-    parser.addPositionalArgument(QStringLiteral("server_url"), QStringLiteral("The url to the server"));
+    parser.addPositionalArgument(QStringLiteral("server_url"), QStringLiteral("The URL to the server"));
     parser.addPositionalArgument(QStringLiteral("remote_folder"), QStringLiteral("A remote folder"));
 
     parser.process(app_args);
@@ -348,15 +314,14 @@ CmdOptions parseOptions(const QStringList &app_args)
 
     const QStringList args = parser.positionalArguments();
     if (args.size() < 2 || args.size() > 3) {
-        parser.showHelp();
-        qApp->exit(EXIT_FAILURE);
+        parser.showHelp(EXIT_FAILURE);
     }
 
     options.source_dir = [arg = args[0]] {
-        QFileInfo fi(arg);
+        const QFileInfo fi(arg);
         if (!fi.exists()) {
-            qCritical() << "Source dir '" << arg << "' does not exist.";
-            qApp->exit(EXIT_FAILURE);
+            qCritical() << "Source dir" << arg << "does not exist.";
+            exit(EXIT_FAILURE);
         }
         QString sourceDir = fi.absoluteFilePath();
         if (!sourceDir.endsWith(QLatin1Char('/'))) {
@@ -378,9 +343,6 @@ CmdOptions parseOptions(const QStringList &app_args)
     if (parser.isSet(trustOption)) {
         options.trustSSL = true;
     }
-    if (parser.isSet(useNetrcOption)) {
-        options.useNetrc = true;
-    }
     if (parser.isSet(nonInterActiveOption)) {
         options.interactive = false;
     }
@@ -417,6 +379,11 @@ CmdOptions parseOptions(const QStringList &app_args)
         Logger::instance()->setLogFile(QStringLiteral("-"));
         Logger::instance()->setLogDebug(true);
     }
+    if (parser.isSet(testCrashReporter)) {
+        // crash onc ethe main loop was started
+        qCritical() << "We'll soon crash on purpose";
+        QTimer::singleShot(0, qApp, &Utility::crash);
+    }
     return options;
 }
 
@@ -433,91 +400,100 @@ int main(int argc, char **argv)
 
     SyncCTX ctx { parseOptions(app.arguments()) };
 
-    if (ctx.options.silent) {
-        qInstallMessageHandler([](QtMsgType, const QMessageLogContext &, const QString &) {});
-    } else {
-        qSetMessagePattern(Logger::loggerPattern());
-    }
+    // start the main loop before we ask for the username etc
+    QTimer::singleShot(0, &app, [&] {
+        if (ctx.options.silent) {
+            qInstallMessageHandler([](QtMsgType, const QMessageLogContext &, const QString &) {});
+        } else {
+            qSetMessagePattern(Logger::loggerPattern());
+        }
 
-    ctx.account = Account::create(QUuid::createUuid());
+        ctx.account = Account::create(QUuid::createUuid());
 
-    if (!ctx.account) {
-        qCritical() << "Could not initialize account!";
-        qApp->exit(EXIT_FAILURE);
-    }
+        if (!ctx.account) {
+            qCritical() << "Could not initialize account!";
+            exit(EXIT_FAILURE);
+        }
 
-    setupCredentials(ctx);
+        setupCredentials(ctx);
 
-    // don't leak credentials more than needed
-    ctx.options.server_url = ctx.options.server_url.adjusted(QUrl::RemoveUserInfo);
-    ctx.options.target_url = ctx.options.target_url.adjusted(QUrl::RemoveUserInfo);
+        // don't leak credentials more than needed
+        ctx.options.server_url = ctx.options.server_url.adjusted(QUrl::RemoveUserInfo);
+        ctx.options.target_url = ctx.options.target_url.adjusted(QUrl::RemoveUserInfo);
 
-    const QUrl baseUrl = [&ctx] {
-        auto tmp = ctx.options.server_url;
-        // Find the folder and the original owncloud url
-        QStringList splitted = tmp.path().split(ctx.account->davPath());
-        tmp.setPath(splitted.value(0));
-        tmp.setScheme(tmp.scheme().replace(QLatin1String("owncloud"), QLatin1String("http")));
-        return tmp;
-    }();
+        const QUrl baseUrl = [&ctx] {
+            auto tmp = ctx.options.server_url;
+            // Find the folder and the original owncloud URL
+            QStringList splitted = tmp.path().split(ctx.account->davPath());
+            tmp.setPath(splitted.value(0));
+            tmp.setScheme(tmp.scheme().replace(QLatin1String("owncloud"), QLatin1String("http")));
+            return tmp;
+        }();
 
 
-    ctx.account->setUrl(baseUrl);
+        ctx.account->setUrl(baseUrl);
 
-    auto *checkServerJob = CheckServerJobFactory(ctx.account->accessManager()).startJob(ctx.account->url(), qApp);
+        auto *checkServerJob = CheckServerJobFactory(ctx.account->accessManager()).startJob(ctx.account->url(), qApp);
 
-    QObject::connect(checkServerJob, &CoreJob::finished, [ctx, checkServerJob] {
-        if (checkServerJob->success()) {
-            // Perform a call to get the capabilities.
-            auto *capabilitiesJob = new JsonApiJob(ctx.account, QStringLiteral("ocs/v1.php/cloud/capabilities"), {}, {}, nullptr);
-            QObject::connect(capabilitiesJob, &JsonApiJob::finishedSignal, qApp, [capabilitiesJob, ctx] {
-                if (capabilitiesJob->reply()->error() != QNetworkReply::NoError || capabilitiesJob->httpStatusCode() != 200) {
-                    qCritical() << "Error connecting to server";
-                    qApp->exit(EXIT_FAILURE);
-                }
-                auto caps = capabilitiesJob->data().value(QStringLiteral("ocs")).toObject().value(QStringLiteral("data")).toObject().value(QStringLiteral("capabilities")).toObject();
-                qDebug() << "Server capabilities" << caps;
-                ctx.account->setCapabilities(caps.toVariantMap());
+        QObject::connect(checkServerJob, &CoreJob::finished, [ctx, checkServerJob] {
+            if (checkServerJob->success()) {
+                // Perform a call to get the capabilities.
+                auto *capabilitiesJob = new JsonApiJob(ctx.account, QStringLiteral("ocs/v1.php/cloud/capabilities"), {}, {}, nullptr);
+                QObject::connect(capabilitiesJob, &JsonApiJob::finishedSignal, qApp, [capabilitiesJob, ctx] {
+                    if (capabilitiesJob->reply()->error() != QNetworkReply::NoError || capabilitiesJob->httpStatusCode() != 200) {
+                        qCritical() << "Error connecting to server";
+                        exit(EXIT_FAILURE);
+                    }
+                    auto caps = capabilitiesJob->data()
+                                    .value(QStringLiteral("ocs"))
+                                    .toObject()
+                                    .value(QStringLiteral("data"))
+                                    .toObject()
+                                    .value(QStringLiteral("capabilities"))
+                                    .toObject();
+                    qDebug() << "Server capabilities" << caps;
+                    ctx.account->setCapabilities({ctx.account->url(), caps.toVariantMap()});
 
-                switch (ctx.account->serverSupportLevel()) {
-                case Account::ServerSupportLevel::Supported:
-                    break;
-                case Account::ServerSupportLevel::Unknown:
-                    qWarning() << "Failed to detect server version";
-                    break;
-                case Account::ServerSupportLevel::Unsupported:
-                    qCritical() << "Error unsupported server";
-                    qApp->exit(EXIT_FAILURE);
-                }
-
-                auto userJob = new JsonApiJob(ctx.account, QStringLiteral("ocs/v1.php/cloud/user"), {}, {}, nullptr);
-                QObject::connect(userJob, &JsonApiJob::finishedSignal, qApp, [userJob, ctx = ctx]() mutable {
-                    const QJsonObject data = userJob->data().value(QStringLiteral("ocs")).toObject().value(QStringLiteral("data")).toObject();
-                    ctx.account->setDavUser(data.value(QStringLiteral("id")).toString());
-                    ctx.account->setDavDisplayName(data.value(QStringLiteral("display-name")).toString());
-
-                    if (ctx.options.server_url == ctx.options.target_url) {
-                        // guess dav path
-                        if (!ctx.options.target_url.path().contains(ctx.account->davPath())) {
-                            ctx.options.target_url = OCC::Utility::concatUrlPath(ctx.options.target_url, ctx.account->davPath());
-                        }
+                    switch (ctx.account->serverSupportLevel()) {
+                    case Account::ServerSupportLevel::Supported:
+                        break;
+                    case Account::ServerSupportLevel::Unknown:
+                        qWarning() << "Failed to detect server version";
+                        break;
+                    case Account::ServerSupportLevel::Unsupported:
+                        qCritical() << "Error unsupported server";
+                        exit(EXIT_FAILURE);
                     }
 
-                    // much lower age than the default since this utility is usually made to be run right after a change in the tests
-                    SyncEngine::minimumFileAgeForUpload = std::chrono::milliseconds(0);
-                    sync(ctx);
+                    auto userJob = new JsonApiJob(ctx.account, QStringLiteral("ocs/v1.php/cloud/user"), {}, {}, nullptr);
+                    QObject::connect(userJob, &JsonApiJob::finishedSignal, qApp, [userJob, ctx = ctx]() mutable {
+                        const QJsonObject data = userJob->data().value(QStringLiteral("ocs")).toObject().value(QStringLiteral("data")).toObject();
+                        ctx.account->setDavUser(data.value(QStringLiteral("id")).toString());
+                        ctx.account->setDavDisplayName(data.value(QStringLiteral("display-name")).toString());
+
+                        if (ctx.options.server_url == ctx.options.target_url) {
+                            // guess dav path
+                            if (!ctx.options.target_url.path().contains(ctx.account->davPath())) {
+                                ctx.options.target_url = OCC::Utility::concatUrlPath(ctx.options.target_url, ctx.account->davPath());
+                            }
+                        }
+
+                        // much lower age than the default since this utility is usually made to be run right after a change in the tests
+                        SyncEngine::minimumFileAgeForUpload = std::chrono::seconds(0);
+                        sync(ctx);
+                    });
+                    userJob->start();
                 });
-                userJob->start();
-            });
-            capabilitiesJob->start();
-        } else {
-            if (checkServerJob->reply()->error() == QNetworkReply::OperationCanceledError) {
-                qCritical() << "Looking up " << ctx.account->url().toString() << " timed out.";
+                capabilitiesJob->start();
             } else {
-                qCritical() << "Failed to resolve " << ctx.account->url().toString() << " Error: " << checkServerJob->reply()->errorString();
+                if (checkServerJob->reply()->error() == QNetworkReply::OperationCanceledError) {
+                    qCritical() << "Looking up " << ctx.account->url().toString() << " timed out.";
+                } else {
+                    qCritical() << "Failed to resolve " << ctx.account->url().toString() << " Error: " << checkServerJob->reply()->errorString();
+                }
+                exit(EXIT_FAILURE);
             }
-            qApp->exit(EXIT_FAILURE);
-        }
+        });
     });
 
     return app.exec();
