@@ -19,7 +19,6 @@
  */
 
 #include "config.h"
-#include "config_csync.h"
 
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
@@ -30,10 +29,9 @@
 #include "common/utility.h"
 #include "common/version.h"
 
-#include <QString>
-#include <QFileInfo>
 #include <QFile>
-#include <QDir>
+#include <QFileInfo>
+#include <QString>
 
 namespace {
 
@@ -97,10 +95,10 @@ OCSYNC_EXPORT void csync_exclude_expand_escapes(QByteArray &input)
 
 /**
  * @brief Checks if filename is considered reserved by Windows
- * @param file_name filename
+ * @param filename filename
  * @return true if file is reserved, false otherwise
  */
-OCSYNC_EXPORT bool csync_is_windows_reserved_word(const QStringRef &filename)
+OCSYNC_EXPORT bool csync_is_windows_reserved_word(QStringView filename)
 {
     size_t len_filename = filename.size();
 
@@ -143,10 +141,10 @@ OCSYNC_EXPORT bool csync_is_windows_reserved_word(const QStringRef &filename)
     return false;
 }
 
-static CSYNC_EXCLUDE_TYPE _csync_excluded_common(const QStringRef &path, bool excludeConflictFiles)
+static CSYNC_EXCLUDE_TYPE _csync_excluded_common(QStringView path, bool excludeConflictFiles)
 {
     /* split up the path */
-    QStringRef bname(path);
+    QStringView bname(path);
     int lastSlash = path.lastIndexOf(QLatin1Char('/'));
     if (lastSlash >= 0) {
         bname = path.mid(lastSlash + 1);
@@ -197,7 +195,7 @@ static CSYNC_EXCLUDE_TYPE _csync_excluded_common(const QStringRef &path, bool ex
     // Filter out characters not allowed in a filename on windows
     // see https://docs.microsoft.com/en-us/windows/desktop/fileio/naming-a-file
     for (auto c : path) {
-        if (c < 32) {
+        if (c.unicode() < 32) {
             return CSYNC_FILE_EXCLUDE_INVALID_CHAR;
         }
         if (std::find_if(
@@ -275,7 +273,7 @@ bool ExcludedFiles::reloadExcludeFiles()
 {
     _allExcludes.clear();
     bool success = true;
-    for (const auto &file : qAsConst(_excludeFiles)) {
+    for (const auto &file : std::as_const(_excludeFiles)) {
         QFile f(file);
         if (!f.open(QIODevice::ReadOnly)) {
             success = false;
@@ -324,18 +322,19 @@ bool ExcludedFiles::versionDirectiveKeepNextLine(const QByteArray &directive) co
     return true;
 }
 
-bool ExcludedFiles::isExcluded(
-    const QString &filePath,
-    const QString &basePath,
-    bool excludeHidden) const
+bool ExcludedFiles::isExcluded(QStringView filePath, QStringView basePath, bool excludeHidden) const
 {
     if (!FileSystem::isChildPathOf(filePath, basePath)) {
         // Mark paths we're not responsible for as excluded...
         return true;
     }
 
-    const QFileInfo fileInfo(filePath);
+    const QFileInfo fileInfo(filePath.toString());
     if (!fileInfo.exists()) {
+        if (excludeHidden && fileInfo.fileName().startsWith(QLatin1Char('.'))) {
+            return true;
+        }
+        // recursively call isExcluded with the path of non-existing file's parent directory
         return isExcluded(fileInfo.path(), basePath, excludeHidden);
     }
 
@@ -349,7 +348,7 @@ bool ExcludedFiles::isExcluded(
             }
 
             // Get the parent path
-            fi = { fi.path() };
+            fi = QFileInfo{fi.path()};
         }
     }
     ItemType type = ItemTypeFile;
@@ -359,14 +358,14 @@ bool ExcludedFiles::isExcluded(
     return isExcludedRemote(filePath, basePath, excludeHidden, type);
 }
 
-bool ExcludedFiles::isExcludedRemote(const QString &filePath, const QString &basePath, bool excludeHidden, ItemType type) const
+bool ExcludedFiles::isExcludedRemote(QStringView filePath, QStringView basePath, bool excludeHidden, ItemType type) const
 {
     if (!FileSystem::isChildPathOf(filePath, basePath)) {
         // Mark paths we're not responsible for as excluded...
         return true;
     }
 
-    auto relativePath = filePath.midRef(basePath.size());
+    auto relativePath = filePath.mid(basePath.size());
     if (relativePath.endsWith(QLatin1Char('/'))) {
         relativePath.chop(1);
     }
@@ -382,7 +381,7 @@ bool ExcludedFiles::isExcludedRemote(const QString &filePath, const QString &bas
     return fullPatternMatch(relativePath, type) != CSYNC_NOT_EXCLUDED;
 }
 
-CSYNC_EXCLUDE_TYPE ExcludedFiles::traversalPatternMatch(const QStringRef &path, ItemType filetype) const
+CSYNC_EXCLUDE_TYPE ExcludedFiles::traversalPatternMatch(QStringView path, ItemType filetype) const
 {
     auto match = _csync_excluded_common(path, _excludeConflictFiles);
     if (match != CSYNC_NOT_EXCLUDED)
@@ -392,7 +391,7 @@ CSYNC_EXCLUDE_TYPE ExcludedFiles::traversalPatternMatch(const QStringRef &path,
 
     // Check the bname part of the path to see whether the full
     // regex should be run.
-    QStringRef bnameStr(path);
+    QStringView bnameStr(path);
     int lastSlash = path.lastIndexOf(QLatin1Char('/'));
     if (lastSlash >= 0) {
         bnameStr = path.mid(lastSlash + 1);
@@ -413,7 +412,7 @@ CSYNC_EXCLUDE_TYPE ExcludedFiles::traversalPatternMatch(const QStringRef &path,
     }
 
     // third capture: full path matching is triggered
-    QStringRef pathStr = path;
+    QStringView pathStr = path;
 
     if (filetype == ItemTypeDirectory) {
         m = _fullTraversalRegexDir.match(pathStr);
@@ -430,7 +429,7 @@ CSYNC_EXCLUDE_TYPE ExcludedFiles::traversalPatternMatch(const QStringRef &path,
     return CSYNC_NOT_EXCLUDED;
 }
 
-CSYNC_EXCLUDE_TYPE ExcludedFiles::fullPatternMatch(const QStringRef &p, ItemType filetype) const
+CSYNC_EXCLUDE_TYPE ExcludedFiles::fullPatternMatch(QStringView p, ItemType filetype) const
 {
     auto match = _csync_excluded_common(p, _excludeConflictFiles);
     if (match != CSYNC_NOT_EXCLUDED)
@@ -628,7 +627,7 @@ void ExcludedFiles::prepare()
         pattern.append(appendMe);
     };
 
-    for (auto exclude : qAsConst(_allExcludes)) {
+    for (auto exclude : std::as_const(_allExcludes)) {
         if (exclude[0] == QLatin1Char('\n'))
             continue; // empty line
         if (exclude[0] == QLatin1Char('\r'))
