@@ -16,24 +16,18 @@
 #include <QtWidgets>
 
 #include "QProgressIndicator.h"
+
 #include "account.h"
 #include "accountmanager.h"
 #include "accountstate.h"
 #include "activitywidget.h"
 #include "commonstrings.h"
-#include "configfile.h"
-#include "folder.h"
-#include "folderman.h"
 #include "issueswidget.h"
-#include "logger.h"
 #include "notificationconfirmjob.h"
 #include "notificationwidget.h"
 #include "openfilemanager.h"
-#include "owncloudpropagator.h"
 #include "protocolwidget.h"
 #include "servernotificationhandler.h"
-#include "syncfileitem.h"
-#include "syncresult.h"
 #include "theme.h"
 
 #include "models/activitylistmodel.h"
@@ -71,8 +65,7 @@ ActivityWidget::ActivityWidget(QWidget *parent)
     header->setSectionResizeMode(QHeaderView::Interactive);
     header->setSortIndicator(static_cast<int>(ActivityListModel::ActivityRole::PointInTime), Qt::DescendingOrder);
 
-    _ui->_notifyLabel->hide();
-    _ui->_notifyScroll->hide();
+    _ui->_notifyGroupBox->hide();
 
     // Create a widget container for the notifications. The ui file defines
     // a scroll area that get a widget with a layout as children
@@ -89,11 +82,11 @@ ActivityWidget::ActivityWidget(QWidget *parent)
         this, &ActivityWidget::slotAccountActivityStatus);
 
     connect(AccountManager::instance(), &AccountManager::accountRemoved, this, [this](AccountStatePtr ast) {
-        if (_accountsWithoutActivities.remove(ast->account()->displayName())) {
+        if (_accountsWithoutActivities.remove(ast->account()->displayNameWithHost())) {
             showLabels();
         }
 
-        for (const auto widget : qAsConst(_widgetForNotifId)) {
+        for (const auto widget : std::as_const(_widgetForNotifId)) {
             if (widget->activity().accountUuid() == ast->account()->uuid()) {
                 scheduleWidgetToRemove(widget);
             }
@@ -112,9 +105,8 @@ ActivityWidget::ActivityWidget(QWidget *parent)
     connect(_ui->_filterButton, &QAbstractButton::clicked, this, [this] {
         ProtocolWidget::showFilterMenu(_ui->_filterButton, _sortModel, static_cast<int>(ActivityListModel::ActivityRole::Account), tr("Account"));
     });
-    connect(_sortModel, &Models::SignalledQSortFilterProxyModel::filterChanged, this, [this]() {
-        _ui->_filterButton->setText(CommonStrings::filterButtonText(_sortModel->filterRegExp().isEmpty() ? 0 : 1));
-    });
+    connect(_sortModel, &Models::SignalledQSortFilterProxyModel::filterChanged, this,
+        [this]() { _ui->_filterButton->setText(CommonStrings::filterButtonText(_sortModel->filterRegularExpression().pattern().isEmpty() ? 0 : 1)); });
 
     connect(&_removeTimer, &QTimer::timeout, this, &ActivityWidget::slotCheckToCleanWidgets);
     _removeTimer.setInterval(1000);
@@ -152,19 +144,15 @@ void ActivityWidget::slotRemoveAccount(const AccountStatePtr &ptr)
 
 void ActivityWidget::showLabels()
 {
-    QString t = tr("Server Activities");
-    _ui->_headerLabel->setTextFormat(Qt::RichText);
-    _ui->_headerLabel->setText(t);
+    _ui->_activityGroupBox->setTitle(tr("&Server Activities"));
+    _ui->_notifyGroupBox->setTitle(tr("&Notifications"));
 
-    _ui->_notifyLabel->setText(tr("Notifications"));
-
-    t.clear();
+    QString bottomText;
     QSetIterator<QString> i(_accountsWithoutActivities);
     while (i.hasNext()) {
-        t.append(tr("<br/>Account %1 does not have activities enabled.").arg(i.next()));
+        bottomText.append(tr("<br/>%1 does not provide activities.").arg(i.next()));
     }
-    _ui->_bottomLabel->setTextFormat(Qt::RichText);
-    _ui->_bottomLabel->setText(t);
+    _ui->_bottomLabel->setText(bottomText);
 }
 
 void ActivityWidget::slotAccountActivityStatus(AccountStatePtr ast, int statusCode)
@@ -173,9 +161,9 @@ void ActivityWidget::slotAccountActivityStatus(AccountStatePtr ast, int statusCo
         return;
     }
     if (statusCode == 999) {
-        _accountsWithoutActivities.insert(ast->account()->displayName());
+        _accountsWithoutActivities.insert(ast->account()->displayNameWithHost());
     } else {
-        _accountsWithoutActivities.remove(ast->account()->displayName());
+        _accountsWithoutActivities.remove(ast->account()->displayNameWithHost());
     }
 
     checkActivityTabVisibility();
@@ -189,13 +177,10 @@ void ActivityWidget::checkActivityTabVisibility()
         _accountsWithoutActivities.count() != accountCount;
     bool hasNotifications = !_widgetForNotifId.isEmpty();
 
-    _ui->_headerLabel->setVisible(hasAccountsWithActivity);
-    _ui->_activityList->setVisible(hasAccountsWithActivity);
+    _ui->_activityGroupBox->setVisible(hasAccountsWithActivity);
+    _ui->_notifyGroupBox->setVisible(hasNotifications);
 
-    _ui->_notifyLabel->setVisible(hasNotifications);
-    _ui->_notifyScroll->setVisible(hasNotifications);
-
-    emit hideActivityTab(!hasAccountsWithActivity && !hasNotifications);
+    Q_EMIT hideActivityTab(!hasAccountsWithActivity && !hasNotifications);
 }
 
 // GUI: Display the notifications.
@@ -208,7 +193,7 @@ void ActivityWidget::slotBuildNotificationDisplay(const ActivityList &list)
         return;
     }
     // compute the count to display later
-    QHash<QString, int> accNotified;
+    QMap<QString, int> accNotified;
 
     // Whether a new notification widget was added to the notificationLayout.
     bool newNotificationShown = false;
@@ -299,23 +284,23 @@ void ActivityWidget::slotBuildNotificationDisplay(const ActivityList &list)
         // Assemble a tray notification
         QString msg;
         if (newGuiLogCount == 1) {
-            msg = tr("%n notifications(s) for %1.", "", accNotified.begin().value()).arg(accNotified.begin().key());
+            msg = tr("%n notification(s) for %1.", "", accNotified.begin().value()).arg(accNotified.begin().key());
         } else if (newGuiLogCount >= 2) {
             const auto acc1 = accNotified.begin();
-            const auto acc2 = acc1 + 1;
+            const auto acc2 = ++accNotified.begin();
             if (newGuiLogCount == 2) {
                 const int notiCount = acc1.value() + acc2.value();
-                msg = tr("%n notifications(s) for %1 and %2.", "", notiCount).arg(acc1.key(), acc2.key());
+                msg = tr("%n notification(s) for %1 and %2.", "", notiCount).arg(acc1.key(), acc2.key());
             } else {
                 msg = tr("New notifications for %1, %2 and other accounts.").arg(acc1.key(), acc2.key());
             }
         }
         const QString log = tr("Open the activity view for details.");
-        emit guiLog(msg, log);
+        Q_EMIT guiLog(msg, log);
     }
 
     if (newNotificationShown) {
-        emit newNotification();
+        Q_EMIT newNotification();
     }
 }
 
@@ -426,8 +411,7 @@ void ActivityWidget::slotCheckToCleanWidgets()
 
     // check to see if the whole notification pane should be hidden
     if (_widgetForNotifId.isEmpty()) {
-        _ui->_notifyLabel->setHidden(true);
-        _ui->_notifyScroll->setHidden(true);
+        _ui->_notifyGroupBox->setHidden(true);
     }
 }
 
@@ -435,6 +419,7 @@ void ActivityWidget::slotItemContextMenu()
 {
     auto rows = _ui->_activityList->selectionModel()->selectedRows();
     auto menu = new QMenu(this);
+    menu->setAccessibleName(tr("Activity item menu"));
     menu->setAttribute(Qt::WA_DeleteOnClose);
 
     // keep in sync with ProtocolWidget::showContextMenu
@@ -454,6 +439,8 @@ void ActivityWidget::slotItemContextMenu()
         }
     }
     menu->popup(QCursor::pos());
+    // accassebility
+    menu->setFocus();
 }
 
 
@@ -473,12 +460,13 @@ ActivitySettings::ActivitySettings(QWidget *parent)
     connect(_activityWidget, &ActivityWidget::hideActivityTab, this, &ActivitySettings::setActivityTabHidden);
     connect(_activityWidget, &ActivityWidget::guiLog, this, &ActivitySettings::guiLog);
     connect(_activityWidget, &ActivityWidget::newNotification, this, &ActivitySettings::slotShowActivityTab);
+    setActivityTabHidden(true);
 
     _protocolWidget = new ProtocolWidget(this);
-    _protocolTabId = _tab->addTab(_protocolWidget, Theme::instance()->syncStateIcon(SyncResult::Success), tr("Sync Protocol"));
+    _protocolTabId = _tab->addTab(_protocolWidget, Resources::getCoreIcon(QStringLiteral("states/sync")), tr("Local Activity"));
 
     _issuesWidget = new IssuesWidget(this);
-    _syncIssueTabId = _tab->addTab(_issuesWidget, Theme::instance()->syncStateIcon(SyncResult::Problem), QString());
+    _syncIssueTabId = _tab->addTab(_issuesWidget, Resources::getCoreIcon(QStringLiteral("states/warning")), QString());
     slotShowIssueItemCount(0); // to display the label.
     connect(_issuesWidget, &IssuesWidget::issueCountUpdated,
         this, &ActivitySettings::slotShowIssueItemCount);
@@ -495,6 +483,9 @@ ActivitySettings::ActivitySettings(QWidget *parent)
 
     // We want the protocol be the default
     _tab->setCurrentIndex(1);
+
+    connect(AccountManager::instance(), &AccountManager::accountRemoved, this,
+        [this](const AccountStatePtr &accountStatePtr) { _timeSinceLastCheck.take(accountStatePtr); });
 }
 
 void ActivitySettings::setNotificationRefreshInterval(std::chrono::milliseconds interval)
