@@ -16,11 +16,13 @@
 #pragma once
 #include "creds/httpcredentials.h"
 #include "creds/oauth.h"
+
 #include <QPointer>
-#include <QTcpServer>
 
 namespace OCC {
 
+class AccountModalWidget;
+
 /**
  * @brief The HttpCredentialsGui class
  * @ingroup gui
@@ -29,24 +31,11 @@ class HttpCredentialsGui : public HttpCredentials
 {
     Q_OBJECT
 public:
-    HttpCredentialsGui()
-        : HttpCredentials()
-    {
-    }
-    HttpCredentialsGui(const QString &user, const QString &password)
-        : HttpCredentials(DetermineAuthTypeJob::AuthType::Basic, user, password)
-    {
-    }
+    HttpCredentialsGui() = default;
 
-    HttpCredentialsGui(const QString &user, const QString &password, const QString &refreshToken)
-        : HttpCredentials(DetermineAuthTypeJob::AuthType::OAuth, user, password)
-    {
-        _refreshToken = refreshToken;
-    }
+    HttpCredentialsGui(const QString &loginUser, const QString &password);
 
-    void openBrowser();
-
-    QUrl authorisationLink() const;
+    HttpCredentialsGui(const QString &davUser, const QString &password, const QString &refreshToken);
 
     /**
      * This will query the server and either uses OAuth via _asyncAuth->start()
@@ -54,24 +43,20 @@ public:
      */
     void askFromUser() override;
 
-    /**
-     * Reset OAuth object and restart authorization process.
-     */
-    void restartOAuth();
 
-private slots:
+private Q_SLOTS:
     void asyncAuthResult(OAuth::Result, const QString &accessToken, const QString &refreshToken);
     void showDialog();
-    void askFromUserAsync();
-
-signals:
-    void authorisationLinkChanged();
 
+Q_SIGNALS:
+    void oAuthLoginAccepted();
     void oAuthErrorOccurred();
 
 private:
+    void startOAuth();
+
     QScopedPointer<AccountBasedOAuth, QScopedPointerObjectDeleteLater<AccountBasedOAuth>> _asyncAuth;
-    QPointer<QWidget> _loginRequiredDialog;
+    QPointer<AccountModalWidget> _modalWidget;
 };
 
 } // namespace OCC
