@@ -13,25 +13,22 @@
  */
 
 
-#ifndef FOLDERMAN_H
-#define FOLDERMAN_H
+#pragma once
 
-#include <QObject>
-#include <QQueue>
-#include <QList>
+#include "gui/owncloudguilib.h"
 
 #include "folder.h"
-#include "folderwatcher.h"
-#include "navigationpanehelper.h"
-#include "syncfileitem.h"
+#include "scheduling/syncscheduler.h"
 
-#include "folderwizard/folderwizard.h"
-
-#include "newwizard/enums.h"
+#include <QList>
+#include <QObject>
+#include <QQueue>
 
 class TestFolderMigration;
 
 namespace OCC {
+
+class FolderMan;
 namespace TestUtils {
     // prototype for test friend
     FolderMan *folderMan();
@@ -82,15 +79,63 @@ private:
  *   (_timeScheduler and slotScheduleFolderByTime()
  *    and Folder::slotSyncFinished())
  */
-class FolderMan : public QObject
+class OWNCLOUDGUI_EXPORT FolderMan : public QObject
 {
     Q_OBJECT
 public:
-    static QString suggestSyncFolder(const QUrl &server, const QString &displayName);
+    /**
+     * For a new folder, the type guides what kind of checks are done to ensure the new folder is not embedded in an existing one.
+     * Or in case of a space folder, that if the new folder is in a Space sync root, it is the sync root of the same account.
+     */
+    enum class NewFolderType {
+        OC10SyncRoot,
+        SpacesSyncRoot,
+        SpacesFolder,
+    };
+
+    struct SyncConnectionDescription
+    {
+        /***
+-         * The WebDAV URL for the sync connection.
+         */
+        QUrl davUrl;
+
+        /***
+         * The id of the space or empty in case of ownCloud 10.
+         */
+        QString spaceId;
+
+        /***
+         * The local folder used for the sync.
+         */
+        QString localPath;
+
+        /***
+         * The relative remote path
+         */
+        QString remotePath;
+
+        /***
+         * The Space name to display in the list of folders or an empty string.
+         */
+        QString displayName;
+
+        /***
+         * Wether to use virtual files.
+         */
+        bool useVirtualFiles;
+
+        uint32_t priority;
+
+        QSet<QString> selectiveSyncBlackList;
+    };
+
+    static QString suggestSyncFolder(NewFolderType folderType, const QUuid &accountUuid);
     [[nodiscard]] static bool prepareFolder(const QString &folder);
 
-    static QString checkPathValidityRecursive(const QString &path);
+    static QString checkPathValidityRecursive(const QString &path, FolderMan::NewFolderType folderType, const QUuid &accountUuid);
 
+    static std::unique_ptr<FolderMan> createInstance();
     ~FolderMan() override;
 
     /**
@@ -100,7 +145,9 @@ public:
     // TODO: use acces throug ocApp and remove that instance pointer
     static FolderMan *instance();
 
-    int setupFolders();
+    /// \returns empty if a downgrade of a folder was detected, otherwise it will return the number
+    ///          of folders that were set up (note: this can be zero when no folders were configured).
+    std::optional<qsizetype> setupFolders();
 
     /** Find folder setting keys that need to be ignored or deleted for being too new.
      *
@@ -119,8 +166,6 @@ public:
      * future configurations (possibly with user confirmation for deletions) and in
      * FolderMan::setupFolders() to know which too-new folder configurations to skip.
      */
-    static void backwardMigrationSettingsKeys(QStringList *deleteKeys, QStringList *ignoreKeys);
-
     const QVector<Folder *> &folders() const;
 
     /** Adds a folder for an account, ensures the journal is gone and saves it in the settings.
@@ -131,8 +176,8 @@ public:
      * Adds a folder for an account. Used to be part of the wizard code base. Constructs the folder definition from the parameters.
      * In case Wizard::SyncMode::SelectiveSync is used, nullptr is returned.
      */
-    Folder *addFolderFromWizard(const AccountStatePtr &accountStatePtr, const QString &localFolder, const QString &remotePath, const QUrl &webDavUrl, const QString &displayName, bool useVfs);
-    Folder *addFolderFromFolderWizardResult(const AccountStatePtr &accountStatePtr, const FolderWizard::Result &config);
+    Folder *addFolderFromWizard(const AccountStatePtr &accountStatePtr, FolderDefinition &&definition, bool useVfs);
+    Folder *addFolderFromFolderWizardResult(const AccountStatePtr &accountStatePtr, const SyncConnectionDescription &config);
 
     /** Removes a folder */
     void removeFolder(Folder *);
@@ -161,9 +206,7 @@ public:
      * @returns false if the journal could not be removed, true otherwise.
      */
     static bool ensureJournalGone(const QString &journalDbFile);
-
-    /** Creates a new and empty local directory. */
-    bool startFromScratch(const QString &);
+    static bool ensureFilesystemSupported(const FolderDefinition &folderDefinition);
 
     /// Produce text for use in the tray tooltip
     static QString trayTooltipStatusString(const SyncResult &result, bool paused);
@@ -175,9 +218,6 @@ public:
     static TrayOverallStatusResult trayOverallStatus(const QVector<Folder *> &folders);
 
     SocketApi *socketApi();
-#ifdef Q_OS_WIN
-    NavigationPaneHelper &navigationPaneHelper() { return _navigationPaneHelper; }
-#endif
 
     /**
      * Check if @a path is a valid path for a new folder considering the already sync'ed items.
@@ -185,7 +225,7 @@ public:
      *
      * @returns an empty string if it is allowed, or an error if it is not allowed
      */
-    QString checkPathValidityForNewFolder(const QString &path) const;
+    QString checkPathValidityForNewFolder(const QString &path, NewFolderType folderType, const QUuid &accountUuid) const;
 
     /**
      * Attempts to find a non-existing, acceptable path for creating a new sync folder.
@@ -196,7 +236,7 @@ public:
      * subfolder of ~ would be a good candidate. When that happens \a basePath
      * is returned.
      */
-    QString findGoodPathForNewSyncFolder(const QString &basePath, const QString &newFolder) const;
+    static QString findGoodPathForNewSyncFolder(const QString &basePath, const QString &newFolder, NewFolderType folderType, const QUuid &accountUuid);
 
     /**
      * While ignoring hidden files can theoretically be switched per folder,
@@ -207,21 +247,6 @@ public:
     bool ignoreHiddenFiles() const;
     void setIgnoreHiddenFiles(bool ignore);
 
-    /**
-     * Access to the current queue of scheduled folders.
-     */
-    QQueue<Folder *> scheduleQueue() const;
-
-    /**
-     * Access to the currently syncing folder.
-     *
-     * Note: This is only the folder that's currently syncing *as-scheduled*. There
-     * may be externally-managed syncs such as from placeholder hydrations.
-     *
-     * See also isAnySyncRunning()
-     */
-    Folder *currentSyncFolder() const;
-
     /**
      * Returns true if any folder is currently syncing.
      *
@@ -239,11 +264,8 @@ public:
      */
     void setSyncEnabled(bool);
 
-    /**
-     * Queues a folder for syncing.
-     * When force is true it will be performed asap.
-     */
-    void scheduleFolder(Folder *folder, bool force = false);
+    SyncScheduler *scheduler() { return _scheduler; }
+
 
     /** Queues all folders for syncing. */
     void scheduleAllFolders();
@@ -256,7 +278,10 @@ public:
 
     /** If the folder configuration is no longer supported this will return an error string */
     Result<void, QString> unsupportedConfiguration(const QString &path) const;
-signals:
+
+    [[nodiscard]] bool isSpaceSynced(GraphApi::Space *space) const;
+
+Q_SIGNALS:
     /**
       * signal to indicate a folder has changed its sync state.
       *
@@ -264,29 +289,19 @@ signals:
       */
     void folderSyncStateChange(Folder *);
 
-    /**
-     * Indicates when the schedule queue changes.
-     */
-    void scheduleQueueChanged();
-
     /**
      * Emitted whenever the list of configured folders changes.
      */
     void folderListChanged();
     void folderRemoved(Folder *folder);
 
-public slots:
+public Q_SLOTS:
 
     /**
      * Schedules folders of newly connected accounts, terminates and
      * de-schedules folders of disconnected accounts.
      */
-    void slotAccountStateChanged();
-
-    /**
-     * restart the client as soon as it is possible, ie. no folders syncing.
-     */
-    void slotScheduleAppRestart();
+    void slotIsConnectedChanged();
 
     /**
      * Triggers a sync run once the lock on the given file is removed.
@@ -296,35 +311,22 @@ public slots:
      */
     void slotSyncOnceFileUnlocks(const QString &path, FileSystem::LockMode mode);
 
-    // slot to schedule an ETag job
-    void slotScheduleETagJob(RequestEtagJob *job);
+    /// This slot will tell all sync engines to reload the sync options.
+    void slotReloadSyncOptions();
 
-private slots:
+private Q_SLOTS:
     void slotFolderSyncPaused(Folder *, bool paused);
     void slotFolderCanSyncChanged();
     void slotFolderSyncStarted();
     void slotFolderSyncFinished(const SyncResult &);
 
-    void slotRunOneEtagJob();
-    void slotEtagJobDestroyed(QObject *);
-
-    // slot to take the next folder from queue and start syncing.
-    void slotStartScheduledFolderSync();
-    void slotEtagPollTimerTimeout();
-
     void slotRemoveFoldersForAccount(const AccountStatePtr &accountState);
 
     void slotServerVersionChanged(Account *account);
 
-    /**
-     * Schedules folders whose time to sync has come.
-     *
-     * Either because a long time has passed since the last sync or
-     * because of previous failures.
-     */
-    void slotScheduleFolderByTime();
-
 private:
+    explicit FolderMan();
+
     /** Adds a new folder, does not add it to the account settings and
      *  does not set an account on the new folder.
       */
@@ -334,9 +336,6 @@ private:
     /* unloads a folder object, does not delete it */
     void unloadFolder(Folder *);
 
-    /** Will start a sync after a bit of delay. */
-    void startScheduledSyncSoon();
-
     // finds all folder configuration files
     // and create the folders
     QString getBackupName(QString fullPathName) const;
@@ -344,53 +343,29 @@ private:
     // makes the folder known to the socket api
     void registerFolderWithSocketApi(Folder *folder);
 
-    // restarts the application (Linux only)
-    void restartApplication();
-
-    void setupFoldersHelper(QSettings &settings, AccountStatePtr account, const QStringList &ignoreKeys, bool backwardsCompatible, bool foldersWithPlaceholders);
+    /// \returns false when a downgrade of the database is detected, true otherwise.
+    bool setupFoldersHelper(QSettings &settings, AccountStatePtr account);
 
     QSet<Folder *> _disabledFolders;
     QVector<Folder *> _folders;
     QString _folderConfigPath;
-    QPointer<Folder> _currentSyncFolder;
-    QPointer<Folder> _lastSyncFolder;
-    bool _syncEnabled;
 
     /// Folder aliases from the settings that weren't read
     QSet<QString> _additionalBlockedFolderAliases;
 
-    /// Starts regular etag query jobs
-    QTimer _etagPollTimer;
-    /// The currently running etag query
-    QPointer<RequestEtagJob> _currentEtagJob;
-
     /// Watches files that couldn't be synced due to locks
     QScopedPointer<LockWatcher> _lockWatcher;
 
-    /// Occasionally schedules folders
-    QTimer _timeScheduler;
-
     /// Scheduled folders that should be synced as soon as possible
-    QQueue<Folder *> _scheduledFolders;
+    SyncScheduler *_scheduler;
 
-    /// Picks the next scheduled folder and starts the sync
-    QTimer _startScheduledSyncTimer;
-
-    QScopedPointer<SocketApi> _socketApi;
-#ifdef Q_OS_WIN
-    NavigationPaneHelper _navigationPaneHelper;
-#endif
-
-    bool _appRestartRequired;
+    std::unique_ptr<SocketApi> _socketApi;
 
     mutable QMap<QString, Result<void, QString>> _unsupportedConfigurationError;
 
     static FolderMan *_instance;
-    explicit FolderMan(QObject *parent = nullptr);
     friend class OCC::Application;
-    friend OCC::FolderMan *OCC::TestUtils::folderMan();
     friend class ::TestFolderMigration;
 };
 
 } // namespace OCC
-#endif // FOLDERMAN_H
