@@ -14,7 +14,7 @@
 #include "spacespage.h"
 #include "ui_spacespage.h"
 
-#include <QModelIndex>
+#include "theme.h"
 
 using namespace OCC;
 
@@ -25,8 +25,10 @@ SpacesPage::SpacesPage(AccountPtr acc, QWidget *parent)
     ui->setupUi(this);
 
     ui->widget->setAccount(acc);
+    ui->label->setText(
+        Theme::instance()->spacesAreCalledFolders() ? tr("Select a folder to sync it to your computer.") : tr("Select a Space to sync it to your computer."));
 
-    connect(ui->widget, &Spaces::SpacesBrowser::selectionChanged, this, &QWizardPage::completeChanged);
+    connect(ui->widget, &Spaces::SpacesBrowser::currentSpaceChanged, this, &QWizardPage::completeChanged);
 }
 
 SpacesPage::~SpacesPage()
@@ -36,10 +38,10 @@ SpacesPage::~SpacesPage()
 
 bool OCC::SpacesPage::isComplete() const
 {
-    return ui->widget->currentSpace().isValid();
+    return ui->widget->currentSpace();
 }
 
-QVariant OCC::SpacesPage::selectedSpace(Spaces::SpacesModel::Columns column) const
+GraphApi::Space *OCC::SpacesPage::currentSpace() const
 {
-    return ui->widget->currentSpace().siblingAtColumn(static_cast<int>(column)).data();
+    return ui->widget->currentSpace();
 }
