@@ -12,23 +12,24 @@
  * for more details.
  */
 
-#ifndef GUIUTILITY_H
-#define GUIUTILITY_H
+#pragma once
+
+#include "gui/owncloudguilib.h"
+
+#include "common/pinstate.h"
 
 #include <QLoggingCategory>
 #include <QString>
 #include <QUrl>
 #include <QWidget>
 
-#include "common/pinstate.h"
-
 namespace OCC {
 
 Q_DECLARE_LOGGING_CATEGORY(lcGuiUtility)
 
 namespace Utility {
 
-    /** Open an url in the browser.
+    /** Open a URL in the browser.
      *
      * If launching the browser fails, display a message.
      */
@@ -41,12 +42,6 @@ namespace Utility {
     bool openEmailComposer(const QString &subject, const QString &body,
         QWidget *errorWidgetParent);
 
-    /** Returns a translated string indicating the current availability.
-     *
-     * This will be used in context menus to describe the current state.
-     */
-    QString vfsCurrentAvailabilityText(VfsItemAvailability availability);
-
     /** Translated text for "making items always available locally" */
     QString vfsPinActionText();
 
@@ -57,7 +52,8 @@ namespace Utility {
 
     QString socketApiSocketPath();
 
+    OWNCLOUDGUI_EXPORT void markDirectoryAsSyncRoot(const QString &path, const QUuid &accountUuid);
+    std::pair<QString, QUuid> getDirectorySyncRootMarkings(const QString &path);
+    void unmarkDirectoryAsSyncRoot(const QString &path);
 } // namespace Utility
 } // namespace OCC
-
-#endif
