@@ -17,8 +17,6 @@
 #include "abstractsetupwizardpage.h"
 #include "setupwizardcontroller.h"
 
-#include <QSharedPointer>
-
 namespace Ui {
 class AccountConfiguredWizardPage;
 }
@@ -30,7 +28,8 @@ class AccountConfiguredWizardPage : public AbstractSetupWizardPage
     Q_OBJECT
 
 public:
-    explicit AccountConfiguredWizardPage(const QString &defaultSyncTargetDir, bool vfsIsAvailable, bool enableVfsByDefault, bool vfsModeIsExperimental);
+    explicit AccountConfiguredWizardPage(
+        const QString &defaultSyncTargetDir, const QString &userChosenSyncTargetDir, bool vfsIsAvailable, bool enableVfsByDefault);
     ~AccountConfiguredWizardPage() noexcept override;
 
     QString syncTargetDir() const;
@@ -39,6 +38,8 @@ public:
 
     bool validateInput() override;
 
+    void setShowAdvancedSettings(bool showAdvancedSettings);
+
 private:
     ::Ui::AccountConfiguredWizardPage *_ui;
 };
