@@ -23,32 +23,28 @@ class Space;
 };
 
 namespace OCC::Spaces {
-class SpacesModel : public QAbstractTableModel
+class SpacesModel : public QAbstractListModel
 {
     Q_OBJECT
 
 public:
-    enum class Columns {
-        Sync,
-        Image,
+    enum class Roles {
+        AccessibleDescriptionRole = Qt::AccessibleDescriptionRole,
+        IsSynced = Qt::UserRole + 1,
         Name,
         Subtitle,
         WebUrl,
         WebDavUrl,
         Priority,
         Enabled,
-
-        ColumnCount,
+        Space,
     };
-    Q_ENUM(Columns)
+    Q_ENUM(Roles)
     explicit SpacesModel(QObject *parent = nullptr);
 
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
-
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
-
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    QHash<int, QByteArray> roleNames() const override;
 
     void setSpacesManager(GraphApi::SpacesManager *spacesManager);
 
