@@ -16,7 +16,6 @@
 #include "common/utility.h"
 #include "ui_tlserrordialog.h"
 
-#include <QAbstractButton>
 #include <QPushButton>
 
 namespace OCC {
@@ -40,6 +39,11 @@ TlsErrorDialog::TlsErrorDialog(const QList<QSslError> &sslErrors, const QString
 
     connect(_ui->buttonBox, &QDialogButtonBox::accepted, this, &TlsErrorDialog::accept);
     connect(_ui->buttonBox, &QDialogButtonBox::rejected, this, &TlsErrorDialog::reject);
+
+    // Try to set the No-button (which will also Q_EMIT the reject signal when cliced) as the default
+    if (QPushButton *noButton = _ui->buttonBox->button(QDialogButtonBox::No)) {
+        noButton->setDefault(true);
+    }
 }
 
 TlsErrorDialog::~TlsErrorDialog()
