@@ -18,8 +18,9 @@
 #include "common/result.h"
 #include "owncloudlib.h"
 
-#include <QSharedPointer>
+#include <QNetworkProxy>
 #include <QSettings>
+#include <QSharedPointer>
 #include <QString>
 #include <QVariant>
 
@@ -116,22 +117,15 @@ public:
      */
     void configureHttpLogging(std::optional<bool> enable = std::nullopt);
 
-    // Whether experimental UI options should be shown
-    bool showExperimentalOptions() const;
-
     // proxy settings
-    void setProxyType(int proxyType,
-        const QString &host = QString(),
-        int port = 0, bool needsAuth = false,
-        const QString &user = QString(),
-        const QString &pass = QString());
+    void setProxyType(
+        QNetworkProxy::ProxyType proxyType, const QString &host = QString(), int port = 0, bool needsAuth = false, const QString &user = QString());
 
     int proxyType() const;
     QString proxyHostName() const;
     int proxyPort() const;
     bool proxyNeedsAuth() const;
     QString proxyUser() const;
-    QString proxyPassword() const;
 
     /** 0: no limit, 1: manual, >0: automatic */
     int useUploadLimit() const;
@@ -143,23 +137,22 @@ public:
     int downloadLimit() const;
     void setUploadLimit(int kbytes);
     void setDownloadLimit(int kbytes);
-    /** [checked, size in MB] **/
-    QPair<bool, qint64> newBigFolderSizeLimit() const;
-    void setNewBigFolderSizeLimit(bool isChecked, qint64 mbytes);
-    bool confirmExternalStorage() const;
-    void setConfirmExternalStorage(bool);
+
+    bool pauseSyncWhenMetered() const;
+    void setPauseSyncWhenMetered(bool isChecked);
 
     /** If we should move the files deleted on the server in the trash  */
     bool moveToTrash() const;
     void setMoveToTrash(bool);
 
+    /// Used for testing, so we do not change the user's config file.
     static bool setConfDir(const QString &value);
 
     bool optionalDesktopNotifications() const;
     void setOptionalDesktopNotifications(bool show);
 
-    bool showInExplorerNavigationPane() const;
-    void setShowInExplorerNavigationPane(bool show);
+    std::optional<QStringList> issuesWidgetFilter() const;
+    void setIssuesWidgetFilter(const QStringList &checked);
 
     std::chrono::seconds timeout() const;
     qint64 chunkSize() const;
@@ -187,8 +180,8 @@ public:
 
     /** The client version that last used this settings file.
         Updated by configVersionMigration() at client startup. */
-    QString clientVersionString() const;
-    void setClientVersionString(const QString &version);
+    QString clientVersionWithBuildNumberString() const;
+    void setClientVersionWithBuildNumberString(const QString &version);
 
     /**  Returns a new settings pre-set in a specific group. */
     static std::unique_ptr<QSettings> settingsWithGroup(const QString &group);
@@ -196,6 +189,15 @@ public:
     /// Add the system and user exclude file path to the ExcludedFiles instance.
     static void setupDefaultExcludeFilePaths(ExcludedFiles &excludedFiles);
 
+    /**
+     * The maximum versions that this client can read.
+     *
+     * We don't use these versions anymore, see https://github.com/owncloud/client/issues/10473 .
+     * These values are only written, and that prevents older clients from loading these newer
+     * settings.
+     */
+    static constexpr int UnusedLegacySettingsVersionNumber = 13;
+
 protected:
     QVariant getPolicySetting(const QString &policy, const QVariant &defaultValue = QVariant()) const;
     void storeData(const QString &group, const QString &key, const QVariant &value);
