@@ -46,17 +46,21 @@ class JsonJob;
  *                +-> Request the user_id is not present
  *                |     |
  *                v     v
- *              finalize(...): emit result(...)
+ *              finalize(...): Q_EMIT result(...)
  *
  */
 class OWNCLOUDSYNC_EXPORT OAuth : public QObject
 {
     Q_OBJECT
 public:
-    enum Result { NotSupported,
-        LoggedIn,
-        Error };
-    Q_ENUM(Result);
+    enum Result { NotSupported, LoggedIn, Error, ErrorInsecureUrl };
+    Q_ENUM(Result)
+    enum class TokenEndpointAuthMethods : char { client_secret_basic, client_secret_post };
+    Q_ENUM(TokenEndpointAuthMethods)
+
+    enum class PromptValuesSupported : char { none = 0, consent = 1 << 0, select_account = 1 << 1, login = 1 << 2, create = 1 << 3 };
+    Q_ENUM(PromptValuesSupported)
+    Q_DECLARE_FLAGS(PromptValuesSupportedFlags, PromptValuesSupported)
 
     OAuth(const QUrl &serverUrl, const QString &davUser, QNetworkAccessManager *networkAccessManager, const QVariantMap &dynamicRegistrationData, QObject *parent);
     ~OAuth() override;
@@ -84,6 +88,8 @@ Q_SIGNALS:
     void dynamicRegistrationDataReceived(const QVariantMap &dynamicRegistrationData);
 
 protected:
+    void updateDynamicRegistration();
+
     QUrl _serverUrl;
     QString _davUser;
     QVariantMap _dynamicRegistrationData;
@@ -97,7 +103,7 @@ protected:
 
     virtual void fetchWellKnown();
 
-    QNetworkReply *postTokenRequest(const QList<QPair<QString, QString>> &queryItems);
+    QNetworkReply *postTokenRequest(QUrlQuery &&queryItems);
 
 
 private:
@@ -113,6 +119,9 @@ private:
     QString _redirectUrl;
     QByteArray _pkceCodeVerifier;
     QByteArray _state;
+
+    TokenEndpointAuthMethods _endpointAuthMethod = TokenEndpointAuthMethods::client_secret_basic;
+    PromptValuesSupportedFlags _supportedPromptValues = {PromptValuesSupported::consent, PromptValuesSupported::select_account};
 };
 
 /**
@@ -142,4 +151,6 @@ private:
     AccountPtr _account;
 };
 
-} // namespce OCC
+QString OWNCLOUDSYNC_EXPORT toString(OAuth::PromptValuesSupportedFlags s);
+Q_DECLARE_OPERATORS_FOR_FLAGS(OAuth::PromptValuesSupportedFlags)
+} // namespace OCC
