@@ -38,16 +38,16 @@ public:
     explicit SyncFileStatusTracker(SyncEngine *syncEngine);
     SyncFileStatus fileStatus(const QString &relativePath);
 
-public slots:
+public Q_SLOTS:
     void slotPathTouched(const QString &fileName);
     // path relative to folder
     void slotAddSilentlyExcluded(const QString &folderPath);
 
-signals:
+Q_SIGNALS:
     void fileStatusChanged(const QString &systemFileName, SyncFileStatus fileStatus);
 
-private slots:
-    void slotAboutToPropagate(SyncFileItemSet &items);
+private Q_SLOTS:
+    void slotAboutToPropagate(const SyncFileItemSet &items);
     void slotItemCompleted(const SyncFileItemPtr &item);
     void slotSyncFinished();
     void slotSyncEngineRunningChanged();
