@@ -29,18 +29,18 @@ void partialUpload(FakeFolder &fakeFolder, const QString &name, quint64 size)
     QVERIFY(fakeFolder.applyLocalModificationsWithoutSync()); // non-vfs test, so force modifications to disk immediately
 
     // Abort when the upload is at 1/3
-    qint64 sizeWhenAbort = -1;
+    std::optional<quint64> sizeWhenAbort;
     auto con = QObject::connect(&fakeFolder.syncEngine(),  &SyncEngine::transmissionProgress,
                                     [&](const ProgressInfo &progress) {
                 if (progress.completedSize() > (progress.totalSize() /3 )) {
                     sizeWhenAbort = progress.completedSize();
-                    fakeFolder.syncEngine().abort();
+                    fakeFolder.syncEngine().abort({});
                 }
     });
 
     QVERIFY(!fakeFolder.applyLocalModificationsAndSync()); // there should have been an error
     QObject::disconnect(con);
-    QVERIFY(sizeWhenAbort > 0);
+    QVERIFY(sizeWhenAbort.has_value());
     QVERIFY(sizeWhenAbort < size);
 
     QCOMPARE(fakeFolder.uploadState().children.count(), 1); // the transfer was done with chunking
@@ -64,18 +64,18 @@ class TestChunkingNG : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
 
     void testFileUpload() {
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
-        const auto size = 10_mb; // 10 MB
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
+        const auto size = 10_MiB; // 10 MB
 
         fakeFolder.localModifier().insert(QStringLiteral("A/a0"), size);
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
         QCOMPARE(fakeFolder.uploadState().children.count(), 1); // the transfer was done with chunking
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size);
 
         // Check that another upload of the same file also work.
         fakeFolder.localModifier().appendByte(QStringLiteral("A/a0"));
@@ -87,22 +87,22 @@ private slots:
     // Test resuming when there's a confusing chunk added
     void testResume1() {
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        const auto size = 10_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const auto size = 10_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
         partialUpload(fakeFolder, QStringLiteral("A/a0"), size);
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
         auto chunkingId = fakeFolder.uploadState().children.first().name;
         const auto &chunkMap = fakeFolder.uploadState().children.first().children;
-        uint64_t uploadedSize = std::accumulate(chunkMap.begin(), chunkMap.end(), 0_mb, [](uint64_t s, const FileInfo &f) { return s + f.contentSize; });
-        QVERIFY(uploadedSize > 2_mb); // at least 2 MB
+        uint64_t uploadedSize = std::accumulate(chunkMap.begin(), chunkMap.end(), 0_MiB, [](uint64_t s, const FileInfo &f) { return s + f.contentSize; });
+        QVERIFY(uploadedSize > 2_MiB); // at least 2 MB
 
         // Add a fake chunk to make sure it gets deleted
         fakeFolder.uploadState().children.first().insert(QStringLiteral("10000"), size);
 
         fakeFolder.setServerOverride([&](QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *) -> QNetworkReply * {
             if (op == QNetworkAccessManager::DeleteOperation) {
-                Q_ASSERT(request.url().path().endsWith("/10000"));
+                Q_ASSERT(request.url().path().endsWith(QStringLiteral("/10000")));
             }
             return nullptr;
         });
@@ -110,7 +110,7 @@ private slots:
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
 
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size);
         // The same chunk id was re-used
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
         QCOMPARE(fakeFolder.uploadState().children.first().name, chunkingId);
@@ -133,8 +133,8 @@ private slots:
 
         // Remove the second chunk, so all further chunks will be deleted and resent
         auto firstChunk = chunkMap.first();
-        auto secondChunk = *(chunkMap.begin() + 1);
-        for (auto it = chunkMap.cbegin() + 2; it != chunkMap.cend(); ++it) {
+        auto secondChunk = *(++chunkMap.begin());
+        for (auto it = ++(++chunkMap.cbegin()); it != chunkMap.cend(); ++it) {
             chunksToDelete.append(it.key());
         }
         fakeFolder.uploadState().children.first().remove(secondChunk.name);
@@ -152,7 +152,7 @@ private slots:
         for (const auto& toDelete : chunksToDelete) {
             bool wasDeleted = false;
             for (const auto& deleted : deletedPaths) {
-                if (deleted.mid(deleted.lastIndexOf('/') + 1) == toDelete) {
+                if (deleted.mid(deleted.lastIndexOf(QLatin1Char('/')) + 1) == toDelete) {
                     wasDeleted = true;
                     break;
                 }
@@ -161,7 +161,7 @@ private slots:
         }
 
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size);
         // The same chunk id was re-used
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
         QCOMPARE(fakeFolder.uploadState().children.first().name, chunkingId);
@@ -170,7 +170,7 @@ private slots:
     // Test resuming when all chunks are already present
     void testResume3() {
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        const auto size = 30_mb;
+        const auto size = 30_MiB;
         setChunkSize(fakeFolder.syncEngine(), 1 * 1000 * 1000);
 
         partialUpload(fakeFolder, QStringLiteral("A/a0"), size);
@@ -178,11 +178,10 @@ private slots:
         auto chunkingId = fakeFolder.uploadState().children.first().name;
         const auto &chunkMap = fakeFolder.uploadState().children.first().children;
         uint64_t uploadedSize = std::accumulate(chunkMap.begin(), chunkMap.end(), 0LL, [](qint64 s, const FileInfo &f) { return s + f.contentSize; });
-        QVERIFY(uploadedSize > 5_mb); // at least 5 MB
+        QVERIFY(uploadedSize > 5_MiB); // at least 5 MB
 
         // Add a chunk that makes the file completely uploaded
-        fakeFolder.uploadState().children.first().insert(
-            QString::number(uploadedSize).rightJustified(16, '0'), size - uploadedSize);
+        fakeFolder.uploadState().children.first().insert(QString::number(uploadedSize).rightJustified(16, QLatin1Char('0')), size - uploadedSize);
 
         bool sawPut = false;
         bool sawDelete = false;
@@ -192,7 +191,7 @@ private slots:
                 sawPut = true;
             } else if (op == QNetworkAccessManager::DeleteOperation) {
                 sawDelete = true;
-            } else if (request.attribute(QNetworkRequest::CustomVerbAttribute) == "MOVE") {
+            } else if (request.attribute(QNetworkRequest::CustomVerbAttribute).toByteArray() == "MOVE") {
                 sawMove = true;
             }
             return nullptr;
@@ -204,7 +203,7 @@ private slots:
         QVERIFY(!sawDelete);
 
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size);
         // The same chunk id was re-used
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
         QCOMPARE(fakeFolder.uploadState().children.first().name, chunkingId);
@@ -214,24 +213,23 @@ private slots:
     // chunk sizes being larger than the file size
     void testResume4() {
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        const auto size = 30_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const auto size = 30_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
         partialUpload(fakeFolder, QStringLiteral("A/a0"), size);
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
         auto chunkingId = fakeFolder.uploadState().children.first().name;
         const auto &chunkMap = fakeFolder.uploadState().children.first().children;
         quint64 uploadedSize = std::accumulate(chunkMap.begin(), chunkMap.end(), 0LL, [](qint64 s, const FileInfo &f) { return s + f.contentSize; });
-        QVERIFY(uploadedSize > 5_mb); // at least 5 MB
+        QVERIFY(uploadedSize > 5_MiB); // at least 5 MB
 
         // Add a chunk that makes the file more than completely uploaded
-        fakeFolder.uploadState().children.first().insert(
-            QString::number(uploadedSize).rightJustified(16, '0'), size - uploadedSize + 100);
+        fakeFolder.uploadState().children.first().insert(QString::number(uploadedSize).rightJustified(16, QLatin1Char('0')), size - uploadedSize + 100);
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
 
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size);
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
     }
 
@@ -240,8 +238,8 @@ private slots:
     void testLateAbortHard()
     {
         FakeFolder fakeFolder{ FileInfo::A12_B12_C12_S12() };
-        const auto size = 15_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const auto size = 15_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
         // Make the MOVE never reply, but trigger a client-abort and apply the change remotely
         QObject parent;
@@ -249,8 +247,8 @@ private slots:
         int nGET = 0;
         const auto responseDelay = 24h; // bigger than abort-wait timeout
         fakeFolder.setServerOverride([&](QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *) -> QNetworkReply * {
-            if (request.attribute(QNetworkRequest::CustomVerbAttribute) == "MOVE") {
-                QTimer::singleShot(50ms, &parent, [&]() { fakeFolder.syncEngine().abort(); });
+            if (request.attribute(QNetworkRequest::CustomVerbAttribute).toByteArray() == "MOVE") {
+                QTimer::singleShot(50ms, &parent, [&]() { fakeFolder.syncEngine().abort({}); });
                 moveChecksumHeader = request.rawHeader("OC-Checksum");
                 return new DelayedReply<FakeChunkMoveReply>(responseDelay, fakeFolder.uploadState(), fakeFolder.remoteModifier(), op, request, &parent);
             } else if (op == QNetworkAccessManager::GetOperation) {
@@ -270,18 +268,18 @@ private slots:
             QCOMPARE(items.size(), 2);
             auto it = items.cbegin();
             QCOMPARE(it->get()->_file, QLatin1String("A"));
-            QCOMPARE(it->get()->_instruction, CSYNC_INSTRUCTION_UPDATE_METADATA);
+            QCOMPARE(it->get()->instruction(), CSYNC_INSTRUCTION_UPDATE_METADATA);
             it++;
             QCOMPARE(it->get()->_file, QLatin1String("A/a0"));
-            QCOMPARE(it->get()->_instruction, CSYNC_INSTRUCTION_UPDATE_METADATA);
-            QCOMPARE(it->get()->_etag, fakeFolder.remoteModifier().find("A/a0")->etag);
+            QCOMPARE(it->get()->instruction(), CSYNC_INSTRUCTION_UPDATE_METADATA);
+            QCOMPARE(it->get()->_etag, QString::fromUtf8(fakeFolder.remoteModifier().find(QStringLiteral("A/a0"))->etag));
         };
         auto checkEtagUpdated = [&](const SyncFileItemPtr &item) {
             if (item->_file == QLatin1String("A/a0")) {
                 SyncJournalFileRecord record;
                 QVERIFY(fakeFolder.syncJournal().getFileRecord(QByteArray("A/a0"), &record));
-                QCOMPARE(record._etag, fakeFolder.remoteModifier().find("A/a0")->etag);
-                QCOMPARE(item->_etag, fakeFolder.remoteModifier().find("A/a0")->etag);
+                QCOMPARE(record._etag, fakeFolder.remoteModifier().find(QStringLiteral("A/a0"))->etag);
+                QCOMPARE(item->_etag, QString::fromUtf8(fakeFolder.remoteModifier().find(QStringLiteral("A/a0"))->etag));
             }
         };
         auto connection1 = connect(&fakeFolder.syncEngine(), &SyncEngine::aboutToPropagate, checkIsUpdateMetaData);
@@ -313,7 +311,7 @@ private slots:
 
         // Set the remote checksum -- the test setup doesn't do it automatically
         QVERIFY(!moveChecksumHeader.isEmpty());
-        fakeFolder.remoteModifier().find("A/a0")->checksums = moveChecksumHeader;
+        fakeFolder.remoteModifier().find(QStringLiteral("A/a0"))->checksums = moveChecksumHeader;
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(nGET, 0); // no new download, just a metadata update!
@@ -328,24 +326,27 @@ private slots:
         // bug: in this case we must expect a re-download of A/A3
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(nGET, 1);
-        QVERIFY(fakeFolder.currentLocalState().find("A/a3"));
+        QVERIFY(fakeFolder.currentLocalState().find(QStringLiteral("A/a3")));
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
 
-    // Check what happens when we abort during the final MOVE and the
-    // the final MOVE is short enough for the abort-delay to help
+    // Check what happens when we abort during the final MOVE.
+    // The move succeeds on the server but as we abort it we won't realize in time.
+    // This means that the current sync fails, as it is aborted, but the MOVE was still performed on the server.
+    // Resulting in the local state being the same as the remote state.
     void testLateAbortRecoverable()
     {
         FakeFolder fakeFolder{ FileInfo::A12_B12_C12_S12() };
-        const auto size = 15_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const auto size = 15_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
         // Make the MOVE never reply, but trigger a client-abort and apply the change remotely
         QObject parent;
         const auto responseDelay = 200ms; // smaller than abort-wait timeout
         fakeFolder.setServerOverride([&](QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *) -> QNetworkReply * {
-            if (request.attribute(QNetworkRequest::CustomVerbAttribute) == "MOVE") {
-                QTimer::singleShot(50ms, &parent, [&]() { fakeFolder.syncEngine().abort(); });
+            if (request.attribute(QNetworkRequest::CustomVerbAttribute).toByteArray() == "MOVE") {
+                QTimer::singleShot(50ms, &parent, [&]() { fakeFolder.syncEngine().abort({}); });
+                // while the response is delayed, the move is performed in the constructor, thus it happens immediately
                 return new DelayedReply<FakeChunkMoveReply>(responseDelay, fakeFolder.uploadState(), fakeFolder.remoteModifier(), op, request, &parent);
             }
             return nullptr;
@@ -353,11 +354,23 @@ private slots:
 
         // Test 1: NEW file aborted
         fakeFolder.localModifier().insert(QStringLiteral("A/a0"), size);
+        // the sync will be aborted and thus fail
+        QVERIFY(!fakeFolder.applyLocalModificationsAndSync());
+        // the move was still performed
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        // update the meta data after the aborted sync
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
         // Test 2: modified file upload aborted
         fakeFolder.localModifier().appendByte(QStringLiteral("A/a0"));
+        // the sync will be aborted and thus fail
+        QVERIFY(!fakeFolder.applyLocalModificationsAndSync());
+        // the move was still performed
+        QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
+
+        // update the meta data after the aborted sync
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
@@ -366,21 +379,21 @@ private slots:
     void testRemoveStale1() {
 
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        const auto size = 10_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const auto size = 10_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
         partialUpload(fakeFolder, QStringLiteral("A/a0"), size);
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
         auto chunkingId = fakeFolder.uploadState().children.first().name;
 
-        const auto a0size = fakeFolder.currentLocalState().find("A/a0")->contentSize;
+        const auto a0size = fakeFolder.currentLocalState().find(QStringLiteral("A/a0"))->contentSize;
         fakeFolder.localModifier().setContents(QStringLiteral("A/a0"), a0size, 'B');
         fakeFolder.localModifier().appendByte(QStringLiteral("A/a0"), 'B');
 
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
 
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size + 1);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size + 1);
         // A different chunk id was used, and the previous one is removed
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
         QVERIFY(fakeFolder.uploadState().children.first().name != chunkingId);
@@ -390,8 +403,8 @@ private slots:
     void testRemoveStale2() {
 
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        const auto size = 10_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const auto size = 10_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
         partialUpload(fakeFolder, QStringLiteral("A/a0"), size);
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
@@ -405,8 +418,8 @@ private slots:
 
     void testCreateConflictWhileSyncing() {
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        const quint64 size = 10_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const quint64 size = 10_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
         // Put a file on the server and download it.
         fakeFolder.remoteModifier().insert(QStringLiteral("A/a0"), size);
@@ -429,7 +442,7 @@ private slots:
 
         QVERIFY(!fakeFolder.applyLocalModificationsAndSync());
         // There was a precondition failed error, this means wen need to sync again
-        QCOMPARE(fakeFolder.syncEngine().isAnotherSyncNeeded(), ImmediateFollowUp);
+        QCOMPARE(fakeFolder.syncEngine().isAnotherSyncNeeded(), true);
 
         QCOMPARE(fakeFolder.uploadState().children.count(), 1); // We did not clean the chunks at this point
 
@@ -439,11 +452,11 @@ private slots:
         auto localState = fakeFolder.currentLocalState();
 
         // A0 is the one from the server
-        QCOMPARE(localState.find("A/a0")->contentSize, size);
-        QCOMPARE(localState.find("A/a0")->contentChar, 'C');
+        QCOMPARE(localState.find(QStringLiteral("A/a0"))->contentSize, size);
+        QCOMPARE(localState.find(QStringLiteral("A/a0"))->contentChar, 'C');
 
         // There is a conflict file with our version
-        auto &stateAChildren = localState.find("A")->children;
+        auto &stateAChildren = localState.find(QStringLiteral("A"))->children;
         auto it = std::find_if(stateAChildren.cbegin(), stateAChildren.cend(), [&](const FileInfo &fi) {
             return fi.name.startsWith(QLatin1String("a0 (conflicted copy"));
         });
@@ -452,7 +465,7 @@ private slots:
         QCOMPARE(it->contentSize, size + 1);
 
         // Remove the conflict file so the comparison works!
-        fakeFolder.localModifier().remove("A/" + it->name);
+        fakeFolder.localModifier().remove(QStringLiteral("A/") + it->name);
         QVERIFY(fakeFolder.applyLocalModificationsWithoutSync());
 
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
@@ -463,8 +476,8 @@ private slots:
     void testModifyLocalFileWhileUploading() {
 
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        const quint64 size = 10_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const quint64 size = 10_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
         fakeFolder.localModifier().insert(QStringLiteral("A/a0"), size, 'A');
 
@@ -485,7 +498,7 @@ private slots:
         QThread::sleep(1);
 
         // There should be a followup sync
-        QCOMPARE(fakeFolder.syncEngine().isAnotherSyncNeeded(), ImmediateFollowUp);
+        QCOMPARE(fakeFolder.syncEngine().isAnotherSyncNeeded(), true);
 
         QCOMPARE(fakeFolder.uploadState().children.count(), 1); // We did not clean the chunks at this point
         auto chunkingId = fakeFolder.uploadState().children.first().name;
@@ -494,7 +507,7 @@ private slots:
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
 
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size + 1);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size + 1);
 
         // A different chunk id was used, and the previous one is removed
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
@@ -516,7 +529,7 @@ private slots:
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
 
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size);
 
         // A different chunk id was used
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
@@ -535,8 +548,8 @@ private slots:
     {
         QFETCH(bool, chunking);
         FakeFolder fakeFolder{ FileInfo::A12_B12_C12_S12() };
-        const auto size = chunking ? 1_mb : 300_b;
-        setChunkSize(fakeFolder.syncEngine(), 300_kb);
+        const auto size = chunking ? 1_MiB : 300_B;
+        setChunkSize(fakeFolder.syncEngine(), 300_KiB);
 
         // Make the MOVE never reply, but trigger a client-abort and apply the change remotely
         QByteArray checksumHeader;
@@ -546,13 +559,12 @@ private slots:
         // This will perform the operation on the server, but the reply will not come to the client
         fakeFolder.setServerOverride([&](QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *outgoingData) -> QNetworkReply * {
             if (!chunking) {
-                Q_ASSERT(!request.url().path().contains("/uploads/")
-                    && "Should not touch uploads endpoint when not chunking");
+                Q_ASSERT(!request.url().path().contains(QStringLiteral("/uploads/")) && "Should not touch uploads endpoint when not chunking");
             }
             if (!chunking && op == QNetworkAccessManager::PutOperation) {
                 checksumHeader = request.rawHeader("OC-Checksum");
                 return new DelayedReply<FakePutReply>(responseDelay, fakeFolder.remoteModifier(), op, request, outgoingData->readAll(), &fakeFolder.syncEngine());
-            } else if (chunking && request.attribute(QNetworkRequest::CustomVerbAttribute) == "MOVE") {
+            } else if (chunking && request.attribute(QNetworkRequest::CustomVerbAttribute).toByteArray() == "MOVE") {
                 checksumHeader = request.rawHeader("OC-Checksum");
                 return new DelayedReply<FakeChunkMoveReply>(responseDelay, fakeFolder.uploadState(), fakeFolder.remoteModifier(), op, request, &fakeFolder.syncEngine());
             } else if (op == QNetworkAccessManager::GetOperation) {
@@ -566,7 +578,7 @@ private slots:
         QVERIFY(!fakeFolder.applyLocalModificationsAndSync()); // timeout!
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState()); // but the upload succeeded
         QVERIFY(!checksumHeader.isEmpty());
-        fakeFolder.remoteModifier().find("A/a0")->checksums = checksumHeader; // The test system don't do that automatically
+        fakeFolder.remoteModifier().find(QStringLiteral("A/a0"))->checksums = checksumHeader; // The test system don't do that automatically
         // Should be resolved properly
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(nGET, 0);
@@ -576,27 +588,27 @@ private slots:
         fakeFolder.localModifier().appendByte(QStringLiteral("A/a0"));
         QVERIFY(!fakeFolder.applyLocalModificationsAndSync()); // timeout!
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState()); // but the upload succeeded
-        fakeFolder.remoteModifier().find("A/a0")->checksums = checksumHeader;
+        fakeFolder.remoteModifier().find(QStringLiteral("A/a0"))->checksums = checksumHeader;
         // modify again, should not cause conflict
         fakeFolder.localModifier().appendByte(QStringLiteral("A/a0"));
         QVERIFY(!fakeFolder.applyLocalModificationsAndSync()); // now it's trying to upload the modified file
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        fakeFolder.remoteModifier().find("A/a0")->checksums = checksumHeader;
+        fakeFolder.remoteModifier().find(QStringLiteral("A/a0"))->checksums = checksumHeader;
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(nGET, 0);
     }
 
     void testPercentEncoding() {
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        const auto size = 5_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const auto size = 5_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
-        fakeFolder.localModifier().insert("A/file % \u20ac", size);
+        fakeFolder.localModifier().insert(QString::fromLatin1("A/file % \u20ac"), size);
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
         // Only the second upload contains an "If" header
-        fakeFolder.localModifier().appendByte("A/file % \u20ac");
+        fakeFolder.localModifier().appendByte(QString::fromLatin1("A/file % \u20ac"));
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
     }
@@ -604,7 +616,7 @@ private slots:
     // Test uploading large files (1 GiB)
     void testVeryBigFiles() {
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
-        const qint64 size = 1_gb; // stay under the INT_MAX (2_gb) limit: QByteArray takes a signed int, so bigger sizes will give weird results.
+        const qint64 size = 1_GiB; // stay under the INT_MAX (2_gb) limit: QByteArray takes a signed int, so bigger sizes will give weird results.
 
         // Partial upload of big files
         partialUpload(fakeFolder, QStringLiteral("A/a0"), size);
@@ -614,7 +626,7 @@ private slots:
         // Now resume
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size);
 
         // The same chunk id was re-used
         QCOMPARE(fakeFolder.uploadState().children.count(), 1);
@@ -625,20 +637,20 @@ private slots:
         fakeFolder.localModifier().appendByte(QStringLiteral("A/a0"));
         QVERIFY(fakeFolder.applyLocalModificationsAndSync());
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QCOMPARE(fakeFolder.currentRemoteState().find("A/a0")->contentSize, size + 1);
+        QCOMPARE(fakeFolder.currentRemoteState().find(QStringLiteral("A/a0"))->contentSize, size + 1);
     }
 
     // the final move fails but the succeeding sync recovers and finishes the upload
     void testFinalMoveLocked()
     {
         FakeFolder fakeFolder { FileInfo::A12_B12_C12_S12() };
-        const auto size = 15_mb;
-        setChunkSize(fakeFolder.syncEngine(), 1_mb);
+        const auto size = 15_MiB;
+        setChunkSize(fakeFolder.syncEngine(), 1_MiB);
 
         OperationCounter counter;
         fakeFolder.setServerOverride([&](QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *device) -> QNetworkReply * {
             counter.serverOverride(op, request, device);
-            if (request.attribute(QNetworkRequest::CustomVerbAttribute) == "MOVE") {
+            if (request.attribute(QNetworkRequest::CustomVerbAttribute).toByteArray() == "MOVE") {
                 return new FakeErrorReply(op, request, this, 423, {});
             }
             return nullptr;
@@ -667,7 +679,7 @@ private slots:
         QCOMPARE(counter.nPUT, 0);
         QCOMPARE(counter.nMOVE, 1);
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
-        QVERIFY(!fakeFolder.syncEngine().isAnotherSyncNeeded());
+        QCOMPARE(fakeFolder.syncEngine().isAnotherSyncNeeded(), false);
     }
 };
 
